hurrecon_summarize_land_water displays information about the current land-water file (land_water.tif).
hurrecon_summarize_tracks displays information about the hurricane tracks that are currently selected.
hurrecon_summarize_site displays peak values for a given hurricane and site.
hurrecon_summarize_region displays summary information for a specified raster file and layer, including number of layers, number of rows and columns, spatial extent, cell height and width, and minimum and maximum value.
hurrecon_summarize_land_water(console = TRUE, hur_path = NULL)hurrecon_summarize_tracks(console = TRUE, hur_path = NULL)
hurrecon_summarize_site(hur_id, site_name, console = TRUE, hur_path = NULL)
hurrecon_summarize_region(
filename,
layer = 1,
subdir = "region",
console = TRUE,
hur_path = NULL
)
a string containing summary information
a string containing summary information
a string containing summary information
a string containing summary information
whether to display results in console
path for current set of model runs
hurricane id
name of site
name of input raster file
number of raster layer
subdirectory where raster file is located (region, region-dt, or region-all)